behave-django
=============

|Build Status| |Latest Version|

Behave BDD integration for Django

Features
--------

-  Web Browser Automation ready
-  Database transactions per scenario
-  Use Django's testing client
-  Use unittest + Django assert library
-  Use behave's command line arguments
-  Use behave's configuration file
-  Fixture loading

Getting started
---------------

`Read the wiki! <https://github.com/mixxorz/behave-django/wiki/Getting-started>`__

Support
-------

behave-django is tested on:

Django 1.4.20, 1.5.12, 1.6.11, 1.7.7, 1.8

Python 2.6, 2.7, 3.3, 3.4

It should work on everything, basically.

Contributing
------------

`Read the quick contributing guide <CONTRIBUTING.md>`__


.. |Build Status| image:: https://travis-ci.org/mixxorz/behave-django.svg?branch=master
   :target: https://travis-ci.org/mixxorz/behave-django
.. |Latest Version| image:: https://pypip.in/version/behave-django/badge.svg
   :target: https://pypi.python.org/pypi/behave-django/
